# MILI Guide

MILI is a barebone immediate mode user interface library. This means that UI elements are created during the game loop and feedback is immediate (it actually has one frame of delay).

The core features of MILI can be found in the MILI object along with the data classes:

## [MILI Class](https://github.com/damusss/mili/blob/main/guide/mili.md)

## [MILI Interaction Data](https://github.com/damusss/mili/blob/main/guide/data.md)

To learn about the styles to use with elements and components, read the style guide:

## [MILI Style](https://github.com/damusss/mili/blob/main/guide/style.md)

MILI also provides useful utilities to manage elements and animations:

## [MILI Utilities](https://github.com/damusss/mili/blob/main/guide/utility.md)

## [MILI Animation](https://github.com/damusss/mili/blob/main/guide/animation.md)

Finally, there are common errors and typehints:

## [MILI Errors and Typehints](https://github.com/damusss/mili/blob/main/guide/extra.md)
